netapp_ontap.models.igroup_initiator_no_records API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.igroup_initiator_no_records`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class IgroupInitiatorNoRecordsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the IgroupInitiatorNoRecords object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `igroup GET POST PATCH`

    The igroup field of the igroup_initiator_no_records.

  `links GET`

    The links field of the igroup_initiator_no_records.

  `name GET POST`

    The FC WWPN, iSCSI IQN, or iSCSI EUI that identifies the host initiator. Valid in POST only and not allowed when the `records` property is used.
    An FC WWPN consist of 16 hexadecimal digits grouped as 8 pairs separated by colons. The format for an iSCSI IQN is iqn.yyyy-mm.reverse_domain_name:any. The iSCSI EUI format consists of the eui. prefix followed by 16 hexadecimal characters.

    Example: iqn.1998-01.com.corp.iscsi:name1